@@ -241,6 +241,7 @@
 //! |tower-compat      | Adapters for `tower::Layer` and `tower::Service`. |
 //! |websocket         | Support for WebSocket          |
 //! | anyhow        | Integrate with the [`anyhow`](https://crates.io/crates/anyhow) crate. |
+//! | i18n          | Support for internationalization |
 
 #![doc(html_favicon_url = "https://raw.githubusercontent.com/poem-web/poem/master/favicon.ico")]
 #![doc(html_logo_url = "https://raw.githubusercontent.com/poem-web/poem/master/logo.png")]
@@ -251,6 +252,9 @@
 
 pub mod endpoint;
 pub mod error;
+#[cfg(feature = "i18n")]
+#[cfg_attr(docsrs, doc(cfg(feature = "i18n")))]
+pub mod i18n;
 pub mod listener;
 pub mod middleware;
 #[cfg(feature = "session")]
